from setuptools import setup, find_packages

setup(
    name='mygeometrysunil',
    version='0.3',
    description='I am ludoo king, Please share OTP here',
    author='Sunil Kumar',
    packages=find_packages(),
)